==> chromium-62.0.3202.75.tar.xz: chromium-62.0.3202.75/chrome/android/java/src/org/chromium/chrome/browser/historyreport/AppIndexingReporter.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.historyreport;

import org.chromium.blink.mojom.document_metadata.WebPage;
import org.chromium.chrome.browser.AppHooks;

/** Base class for reporting entities to App Indexing. */
public class AppIndexingReporter {
    private static final String TAG = "AppIndexingReporter";
    private static AppIndexingReporter sInstance;

    public static AppIndexingReporter getInstance() {
        if (sInstance == null) {
            sInstance = AppHooks.get().createAppIndexingReporter();
        }
        return sInstance;
    }

    /**
     * Reports provided entity to on-device index.
     * Base class does not implement any reporting, and call is a no-op. Child classes should
     * implement this functionality.
     */
    public void reportWebPage(WebPage webpage) {
        // Overriden by private class. Base class does nothing.
    }

    /**
     * Reports view of provided url to on-device index.
     * Base class does not implement any reporting, and call is a no-op. Child classes should
     * implement this functionality.
     */
    public void reportWebPageView(String url, String title) {
        // Overriden by private class. Base class does nothing.
    }

    /**
     * Clears history of reported entities.
     * Currently, we do not support clearing only a subset of history. Base class does not implement
     * any reporting, and call is a no-op. Child classes should implement this functionality.
     */
    public void clearHistory() {
        // Overriden by private class. Base class does nothing.
    }
}

==> chromium_113.0.5672.126.orig.tar.xz: chromium-113.0.5672.126/chrome/android/java/src/org/chromium/chrome/browser/historyreport/AppIndexingReporter.java <==
// Copyright 2017 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.chrome.browser.historyreport;

import org.chromium.blink.mojom.WebPage;
import org.chromium.chrome.browser.AppHooks;

/** Base class for reporting entities to App Indexing. */
public class AppIndexingReporter {
    private static AppIndexingReporter sInstance;

    public static AppIndexingReporter getInstance() {
        if (sInstance == null) {
            sInstance = AppHooks.get().createAppIndexingReporter();
        }
        return sInstance;
    }

    /**
     * Reports provided entity to on-device index.
     * Base class does not implement any reporting, and call is a no-op. Child classes should
     * implement this functionality.
     */
    public void reportWebPage(WebPage webpage) {
        // Overridden by private class. Base class does nothing.
    }

    /**
     * Reports view of provided url to on-device index.
     * Base class does not implement any reporting, and call is a no-op. Child classes should
     * implement this functionality.
     */
    public void reportWebPageView(String url, String title) {
        // Overridden by private class. Base class does nothing.
    }

    /**
     * Clears history of reported entities.
     * Currently, we do not support clearing only a subset of history. Base class does not implement
     * any reporting, and call is a no-op. Child classes should implement this functionality.
     */
    public void clearHistory() {
        // Overridden by private class. Base class does nothing.
    }
}
